#include "gamestickthread.h"
#include "gamestickmessage.h"
#include <Application.h>
#include <stdio.h>

//========================================================
// Class: BTSGameStickThread
//
// This class is meant to feed commands to the game engine.
// The joystick is sampled 15 times a second.  Whenever there
// is input that indicates the user wants to move in a particular
// direction, a command is sent to the game engine.
//
// Sampling at 15 times a second should be fast enough to be
// responsive to the fastest game play.  A better method would be
// to make the sampling double the rate of the game speed.
//========================================================
BTSGameStickThread::BTSGameStickThread()
	: ATicker(5),
	fGameStick(GAMEPORT1)
{
}

BTSGameStickThread::BTSGameStickThread(EGamePort whichone)
	: ATicker(5),
	fGameStick(whichone)
{
}

//========================================================
// Method: Tick
//
// The Tick method is called once per time interval of 
// the clock.
//
// The idea here is to send a command to the game engine
// if the user is pressing the joystick far enough in
// a particular direction.  The threshold is set at such
// a level that the user doesn't have to push the stick all
// the way to the edge, but it will not trigger if the bump
// it just a tiny bit.
//
// The x direction is favored over the y direction if they
// are both activated.
//
// This method works particularly well with the gamepad type
// of joystick where there is a thumb control.
//========================================================
void
BTSGameStickThread::Tick(const double tickCount)
{
	if (!fGameStick.IsButtonPressed(BUTTON1|BUTTON2))
		return;
		
	// If the user presses button 2, that's our signal
	// to recalibrate the zero position.
	if (fGameStick.IsButtonPressed(BUTTON2))
	{
		float x, y;
		fGameStick.FindZero(x,y);
	}
		
	fGameStick.Update();
	BTSGameStickMessage *msg = new BTSGameStickMessage(fGameStick);
	
	be_app->PostMessage(msg);
}
